# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/stream/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.exchange.v1beta1 import events_pb2 as injective_dot_exchange_dot_v1beta1_dot_events__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/stream/v1beta1/query.proto\x12\x18injective.stream.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\'injective/exchange/v1beta1/events.proto\x1a)injective/exchange/v1beta1/exchange.proto\"\xb6\x06\n\rStreamRequest\x12P\n\x14\x62\x61nk_balances_filter\x18\x01 \x01(\x0b\x32,.injective.stream.v1beta1.BankBalancesFilterB\x04\xc8\xde\x1f\x01\x12\\\n\x1asubaccount_deposits_filter\x18\x02 \x01(\x0b\x32\x32.injective.stream.v1beta1.SubaccountDepositsFilterB\x04\xc8\xde\x1f\x01\x12H\n\x12spot_trades_filter\x18\x03 \x01(\x0b\x32&.injective.stream.v1beta1.TradesFilterB\x04\xc8\xde\x1f\x01\x12N\n\x18\x64\x65rivative_trades_filter\x18\x04 \x01(\x0b\x32&.injective.stream.v1beta1.TradesFilterB\x04\xc8\xde\x1f\x01\x12H\n\x12spot_orders_filter\x18\x05 \x01(\x0b\x32&.injective.stream.v1beta1.OrdersFilterB\x04\xc8\xde\x1f\x01\x12N\n\x18\x64\x65rivative_orders_filter\x18\x06 \x01(\x0b\x32&.injective.stream.v1beta1.OrdersFilterB\x04\xc8\xde\x1f\x01\x12O\n\x16spot_orderbooks_filter\x18\x07 \x01(\x0b\x32).injective.stream.v1beta1.OrderbookFilterB\x04\xc8\xde\x1f\x01\x12U\n\x1c\x64\x65rivative_orderbooks_filter\x18\x08 \x01(\x0b\x32).injective.stream.v1beta1.OrderbookFilterB\x04\xc8\xde\x1f\x01\x12I\n\x10positions_filter\x18\t \x01(\x0b\x32).injective.stream.v1beta1.PositionsFilterB\x04\xc8\xde\x1f\x01\x12N\n\x13oracle_price_filter\x18\n \x01(\x0b\x32+.injective.stream.v1beta1.OraclePriceFilterB\x04\xc8\xde\x1f\x01\"\xe0\x05\n\x0eStreamResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x04\x12\x12\n\nblock_time\x18\x02 \x01(\x03\x12<\n\rbank_balances\x18\x03 \x03(\x0b\x32%.injective.stream.v1beta1.BankBalance\x12I\n\x13subaccount_deposits\x18\x04 \x03(\x0b\x32,.injective.stream.v1beta1.SubaccountDeposits\x12\x38\n\x0bspot_trades\x18\x05 \x03(\x0b\x32#.injective.stream.v1beta1.SpotTrade\x12\x44\n\x11\x64\x65rivative_trades\x18\x06 \x03(\x0b\x32).injective.stream.v1beta1.DerivativeTrade\x12>\n\x0bspot_orders\x18\x07 \x03(\x0b\x32).injective.stream.v1beta1.SpotOrderUpdate\x12J\n\x11\x64\x65rivative_orders\x18\x08 \x03(\x0b\x32/.injective.stream.v1beta1.DerivativeOrderUpdate\x12I\n\x16spot_orderbook_updates\x18\t \x03(\x0b\x32).injective.stream.v1beta1.OrderbookUpdate\x12O\n\x1c\x64\x65rivative_orderbook_updates\x18\n \x03(\x0b\x32).injective.stream.v1beta1.OrderbookUpdate\x12\x35\n\tpositions\x18\x0b \x03(\x0b\x32\".injective.stream.v1beta1.Position\x12<\n\roracle_prices\x18\x0c \x03(\x0b\x32%.injective.stream.v1beta1.OraclePrice\"V\n\x0fOrderbookUpdate\x12\x0b\n\x03seq\x18\x01 \x01(\x04\x12\x36\n\torderbook\x18\x02 \x01(\x0b\x32#.injective.stream.v1beta1.Orderbook\"\x8d\x01\n\tOrderbook\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x35\n\nbuy_levels\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\x12\x36\n\x0bsell_levels\x18\x03 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\"}\n\x0b\x42\x61nkBalance\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12]\n\x08\x62\x61lances\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"p\n\x12SubaccountDeposits\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x43\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32+.injective.stream.v1beta1.SubaccountDepositB\x04\xc8\xde\x1f\x00\"^\n\x11SubaccountDeposit\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12:\n\x07\x64\x65posit\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.DepositB\x04\xc8\xde\x1f\x00\"\xa3\x01\n\x0fSpotOrderUpdate\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.injective.stream.v1beta1.OrderUpdateStatus\x12\x12\n\norder_hash\x18\x02 \x01(\x0c\x12\x0b\n\x03\x63id\x18\x03 \x01(\t\x12\x32\n\x05order\x18\x04 \x01(\x0b\x32#.injective.stream.v1beta1.SpotOrder\"_\n\tSpotOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\x05order\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderB\x04\xc8\xde\x1f\x00\"\xaf\x01\n\x15\x44\x65rivativeOrderUpdate\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.injective.stream.v1beta1.OrderUpdateStatus\x12\x12\n\norder_hash\x18\x02 \x01(\x0c\x12\x0b\n\x03\x63id\x18\x03 \x01(\t\x12\x38\n\x05order\x18\x04 \x01(\x0b\x32).injective.stream.v1beta1.DerivativeOrder\"~\n\x0f\x44\x65rivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x45\n\x05order\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x00\x12\x11\n\tis_market\x18\x03 \x01(\x08\"\xdd\x02\n\x08Position\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x0e\n\x06isLong\x18\x03 \x01(\x08\x12@\n\x08quantity\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x43\n\x0b\x65ntry_price\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12>\n\x06margin\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12P\n\x18\x63umulative_funding_entry\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"j\n\x0bOraclePrice\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x0c\n\x04type\x18\x03 \x01(\t\"\xe0\x02\n\tSpotTrade\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0e\n\x06is_buy\x18\x02 \x01(\x08\x12\x15\n\rexecutionType\x18\x03 \x01(\t\x12@\n\x08quantity\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12=\n\x05price\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x15\n\rsubaccount_id\x18\x06 \x01(\t\x12;\n\x03\x66\x65\x65\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x12\n\norder_hash\x18\x08 \x01(\x0c\x12#\n\x15\x66\x65\x65_recipient_address\x18\t \x01(\tB\x04\xc8\xde\x1f\x01\x12\x0b\n\x03\x63id\x18\n \x01(\t\"\xe8\x02\n\x0f\x44\x65rivativeTrade\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0e\n\x06is_buy\x18\x02 \x01(\x08\x12\x15\n\rexecutionType\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t\x12\x41\n\x0eposition_delta\x18\x05 \x01(\x0b\x32).injective.exchange.v1beta1.PositionDelta\x12>\n\x06payout\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12;\n\x03\x66\x65\x65\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x12\n\norder_hash\x18\x08 \x01(\t\x12#\n\x15\x66\x65\x65_recipient_address\x18\t \x01(\tB\x04\xc8\xde\x1f\x01\x12\x0b\n\x03\x63id\x18\n \x01(\t\":\n\x0cTradesFilter\x12\x16\n\x0esubaccount_ids\x18\x01 \x03(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\"=\n\x0fPositionsFilter\x12\x16\n\x0esubaccount_ids\x18\x01 \x03(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\":\n\x0cOrdersFilter\x12\x16\n\x0esubaccount_ids\x18\x01 \x03(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\"%\n\x0fOrderbookFilter\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"&\n\x12\x42\x61nkBalancesFilter\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\"2\n\x18SubaccountDepositsFilter\x12\x16\n\x0esubaccount_ids\x18\x01 \x03(\t\"#\n\x11OraclePriceFilter\x12\x0e\n\x06symbol\x18\x01 \x03(\t*L\n\x11OrderUpdateStatus\x12\x0f\n\x0bUnspecified\x10\x00\x12\n\n\x06\x42ooked\x10\x01\x12\x0b\n\x07Matched\x10\x02\x12\r\n\tCancelled\x10\x03\x32g\n\x06Stream\x12]\n\x06Stream\x12\'.injective.stream.v1beta1.StreamRequest\x1a(.injective.stream.v1beta1.StreamResponse0\x01\x42\x46ZDgithub.com/InjectiveLabs/injective-core/injective-chain/stream/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.stream.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/InjectiveLabs/injective-core/injective-chain/stream/types'
  _STREAMREQUEST.fields_by_name['bank_balances_filter']._options = None
  _STREAMREQUEST.fields_by_name['bank_balances_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['subaccount_deposits_filter']._options = None
  _STREAMREQUEST.fields_by_name['subaccount_deposits_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['spot_trades_filter']._options = None
  _STREAMREQUEST.fields_by_name['spot_trades_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['derivative_trades_filter']._options = None
  _STREAMREQUEST.fields_by_name['derivative_trades_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['spot_orders_filter']._options = None
  _STREAMREQUEST.fields_by_name['spot_orders_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['derivative_orders_filter']._options = None
  _STREAMREQUEST.fields_by_name['derivative_orders_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['spot_orderbooks_filter']._options = None
  _STREAMREQUEST.fields_by_name['spot_orderbooks_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['derivative_orderbooks_filter']._options = None
  _STREAMREQUEST.fields_by_name['derivative_orderbooks_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['positions_filter']._options = None
  _STREAMREQUEST.fields_by_name['positions_filter']._serialized_options = b'\310\336\037\001'
  _STREAMREQUEST.fields_by_name['oracle_price_filter']._options = None
  _STREAMREQUEST.fields_by_name['oracle_price_filter']._serialized_options = b'\310\336\037\001'
  _BANKBALANCE.fields_by_name['balances']._options = None
  _BANKBALANCE.fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SUBACCOUNTDEPOSITS.fields_by_name['deposits']._options = None
  _SUBACCOUNTDEPOSITS.fields_by_name['deposits']._serialized_options = b'\310\336\037\000'
  _SUBACCOUNTDEPOSIT.fields_by_name['deposit']._options = None
  _SUBACCOUNTDEPOSIT.fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _SPOTORDER.fields_by_name['order']._options = None
  _SPOTORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _DERIVATIVEORDER.fields_by_name['order']._options = None
  _DERIVATIVEORDER.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _POSITION.fields_by_name['quantity']._options = None
  _POSITION.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _POSITION.fields_by_name['entry_price']._options = None
  _POSITION.fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _POSITION.fields_by_name['margin']._options = None
  _POSITION.fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _POSITION.fields_by_name['cumulative_funding_entry']._options = None
  _POSITION.fields_by_name['cumulative_funding_entry']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _ORACLEPRICE.fields_by_name['price']._options = None
  _ORACLEPRICE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTTRADE.fields_by_name['quantity']._options = None
  _SPOTTRADE.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTTRADE.fields_by_name['price']._options = None
  _SPOTTRADE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTTRADE.fields_by_name['fee']._options = None
  _SPOTTRADE.fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTTRADE.fields_by_name['fee_recipient_address']._options = None
  _SPOTTRADE.fields_by_name['fee_recipient_address']._serialized_options = b'\310\336\037\001'
  _DERIVATIVETRADE.fields_by_name['payout']._options = None
  _DERIVATIVETRADE.fields_by_name['payout']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVETRADE.fields_by_name['fee']._options = None
  _DERIVATIVETRADE.fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVETRADE.fields_by_name['fee_recipient_address']._options = None
  _DERIVATIVETRADE.fields_by_name['fee_recipient_address']._serialized_options = b'\310\336\037\001'
  _globals['_ORDERUPDATESTATUS']._serialized_start=4435
  _globals['_ORDERUPDATESTATUS']._serialized_end=4511
  _globals['_STREAMREQUEST']._serialized_start=205
  _globals['_STREAMREQUEST']._serialized_end=1027
  _globals['_STREAMRESPONSE']._serialized_start=1030
  _globals['_STREAMRESPONSE']._serialized_end=1766
  _globals['_ORDERBOOKUPDATE']._serialized_start=1768
  _globals['_ORDERBOOKUPDATE']._serialized_end=1854
  _globals['_ORDERBOOK']._serialized_start=1857
  _globals['_ORDERBOOK']._serialized_end=1998
  _globals['_BANKBALANCE']._serialized_start=2000
  _globals['_BANKBALANCE']._serialized_end=2125
  _globals['_SUBACCOUNTDEPOSITS']._serialized_start=2127
  _globals['_SUBACCOUNTDEPOSITS']._serialized_end=2239
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=2241
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=2335
  _globals['_SPOTORDERUPDATE']._serialized_start=2338
  _globals['_SPOTORDERUPDATE']._serialized_end=2501
  _globals['_SPOTORDER']._serialized_start=2503
  _globals['_SPOTORDER']._serialized_end=2598
  _globals['_DERIVATIVEORDERUPDATE']._serialized_start=2601
  _globals['_DERIVATIVEORDERUPDATE']._serialized_end=2776
  _globals['_DERIVATIVEORDER']._serialized_start=2778
  _globals['_DERIVATIVEORDER']._serialized_end=2904
  _globals['_POSITION']._serialized_start=2907
  _globals['_POSITION']._serialized_end=3256
  _globals['_ORACLEPRICE']._serialized_start=3258
  _globals['_ORACLEPRICE']._serialized_end=3364
  _globals['_SPOTTRADE']._serialized_start=3367
  _globals['_SPOTTRADE']._serialized_end=3719
  _globals['_DERIVATIVETRADE']._serialized_start=3722
  _globals['_DERIVATIVETRADE']._serialized_end=4082
  _globals['_TRADESFILTER']._serialized_start=4084
  _globals['_TRADESFILTER']._serialized_end=4142
  _globals['_POSITIONSFILTER']._serialized_start=4144
  _globals['_POSITIONSFILTER']._serialized_end=4205
  _globals['_ORDERSFILTER']._serialized_start=4207
  _globals['_ORDERSFILTER']._serialized_end=4265
  _globals['_ORDERBOOKFILTER']._serialized_start=4267
  _globals['_ORDERBOOKFILTER']._serialized_end=4304
  _globals['_BANKBALANCESFILTER']._serialized_start=4306
  _globals['_BANKBALANCESFILTER']._serialized_end=4344
  _globals['_SUBACCOUNTDEPOSITSFILTER']._serialized_start=4346
  _globals['_SUBACCOUNTDEPOSITSFILTER']._serialized_end=4396
  _globals['_ORACLEPRICEFILTER']._serialized_start=4398
  _globals['_ORACLEPRICEFILTER']._serialized_end=4433
  _globals['_STREAM']._serialized_start=4513
  _globals['_STREAM']._serialized_end=4616
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmwasm/wasm/v1/query.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x11\x61mino/amino.proto\"+\n\x18QueryContractInfoRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"|\n\x19QueryContractInfoResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12H\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\x11\xc8\xde\x1f\x00\xd0\xde\x1f\x01\xea\xde\x1f\x00\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x01\"j\n\x1bQueryContractHistoryRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xa3\x01\n\x1cQueryContractHistoryResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.cosmwasm.wasm.v1.ContractCodeHistoryEntryB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"j\n\x1bQueryContractsByCodeRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"n\n\x1cQueryContractsByCodeResponse\x12\x11\n\tcontracts\x18\x01 \x03(\t\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"k\n\x1cQueryAllContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x90\x01\n\x1dQueryAllContractStateResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"C\n\x1cQueryRawContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\nquery_data\x18\x02 \x01(\x0c\"-\n\x1dQueryRawContractStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"]\n\x1eQuerySmartContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12*\n\nquery_data\x18\x02 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"G\n\x1fQuerySmartContractStateResponse\x12$\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"#\n\x10QueryCodeRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\"\xec\x01\n\x10\x43odeInfoResponse\x12!\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\x10\xe2\xde\x1f\x06\x43odeID\xea\xde\x1f\x02id\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12G\n\tdata_hash\x18\x03 \x01(\x0c\x42\x34\xfa\xde\x1f\x30github.com/cometbft/cometbft/libs/bytes.HexBytes\x12I\n\x16instantiate_permission\x18\x06 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x01J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"r\n\x11QueryCodeResponse\x12?\n\tcode_info\x18\x01 \x01(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\x08\xd0\xde\x1f\x01\xea\xde\x1f\x00\x12\x16\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61ta:\x04\xe8\xa0\x1f\x01\"O\n\x11QueryCodesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x94\x01\n\x12QueryCodesResponse\x12\x41\n\ncode_infos\x18\x01 \x03(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"U\n\x17QueryPinnedCodesRequest\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"v\n\x18QueryPinnedCodesResponse\x12\x1d\n\x08\x63ode_ids\x18\x01 \x03(\x04\x42\x0b\xe2\xde\x1f\x07\x43odeIDs\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.cosmwasm.wasm.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"u\n\x1eQueryContractsByCreatorRequest\x12\x17\n\x0f\x63reator_address\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"z\n\x1fQueryContractsByCreatorResponse\x12\x1a\n\x12\x63ontract_addresses\x18\x01 \x03(\t\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xc3\r\n\x05Query\x12\x95\x01\n\x0c\x43ontractInfo\x12*.cosmwasm.wasm.v1.QueryContractInfoRequest\x1a+.cosmwasm.wasm.v1.QueryContractInfoResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmwasm/wasm/v1/contract/{address}\x12\xa6\x01\n\x0f\x43ontractHistory\x12-.cosmwasm.wasm.v1.QueryContractHistoryRequest\x1a..cosmwasm.wasm.v1.QueryContractHistoryResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmwasm/wasm/v1/contract/{address}/history\x12\xa4\x01\n\x0f\x43ontractsByCode\x12-.cosmwasm.wasm.v1.QueryContractsByCodeRequest\x1a..cosmwasm.wasm.v1.QueryContractsByCodeResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/code/{code_id}/contracts\x12\xa7\x01\n\x10\x41llContractState\x12..cosmwasm.wasm.v1.QueryAllContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryAllContractStateResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/contract/{address}/state\x12\xb2\x01\n\x10RawContractState\x12..cosmwasm.wasm.v1.QueryRawContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryRawContractStateResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}\x12\xba\x01\n\x12SmartContractState\x12\x30.cosmwasm.wasm.v1.QuerySmartContractStateRequest\x1a\x31.cosmwasm.wasm.v1.QuerySmartContractStateResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}\x12y\n\x04\x43ode\x12\".cosmwasm.wasm.v1.QueryCodeRequest\x1a#.cosmwasm.wasm.v1.QueryCodeResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmwasm/wasm/v1/code/{code_id}\x12r\n\x05\x43odes\x12#.cosmwasm.wasm.v1.QueryCodesRequest\x1a$.cosmwasm.wasm.v1.QueryCodesResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmwasm/wasm/v1/code\x12\x8c\x01\n\x0bPinnedCodes\x12).cosmwasm.wasm.v1.QueryPinnedCodesRequest\x1a*.cosmwasm.wasm.v1.QueryPinnedCodesResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmwasm/wasm/v1/codes/pinned\x12}\n\x06Params\x12$.cosmwasm.wasm.v1.QueryParamsRequest\x1a%.cosmwasm.wasm.v1.QueryParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmwasm/wasm/v1/codes/params\x12\xb8\x01\n\x12\x43ontractsByCreator\x12\x30.cosmwasm.wasm.v1.QueryContractsByCreatorRequest\x1a\x31.cosmwasm.wasm.v1.QueryContractsByCreatorResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmwasm/wasm/v1/contracts/creator/{creator_address}B0Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\250\342\036\000'
  _QUERYCONTRACTINFORESPONSE.fields_by_name['contract_info']._options = None
  _QUERYCONTRACTINFORESPONSE.fields_by_name['contract_info']._serialized_options = b'\310\336\037\000\320\336\037\001\352\336\037\000\250\347\260*\001'
  _QUERYCONTRACTINFORESPONSE._options = None
  _QUERYCONTRACTINFORESPONSE._serialized_options = b'\350\240\037\001'
  _QUERYCONTRACTHISTORYRESPONSE.fields_by_name['entries']._options = None
  _QUERYCONTRACTHISTORYRESPONSE.fields_by_name['entries']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYALLCONTRACTSTATERESPONSE.fields_by_name['models']._options = None
  _QUERYALLCONTRACTSTATERESPONSE.fields_by_name['models']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYSMARTCONTRACTSTATEREQUEST.fields_by_name['query_data']._options = None
  _QUERYSMARTCONTRACTSTATEREQUEST.fields_by_name['query_data']._serialized_options = b'\372\336\037\022RawContractMessage'
  _QUERYSMARTCONTRACTSTATERESPONSE.fields_by_name['data']._options = None
  _QUERYSMARTCONTRACTSTATERESPONSE.fields_by_name['data']._serialized_options = b'\372\336\037\022RawContractMessage'
  _CODEINFORESPONSE.fields_by_name['code_id']._options = None
  _CODEINFORESPONSE.fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID\352\336\037\002id'
  _CODEINFORESPONSE.fields_by_name['data_hash']._options = None
  _CODEINFORESPONSE.fields_by_name['data_hash']._serialized_options = b'\372\336\0370github.com/cometbft/cometbft/libs/bytes.HexBytes'
  _CODEINFORESPONSE.fields_by_name['instantiate_permission']._options = None
  _CODEINFORESPONSE.fields_by_name['instantiate_permission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _CODEINFORESPONSE._options = None
  _CODEINFORESPONSE._serialized_options = b'\350\240\037\001'
  _QUERYCODERESPONSE.fields_by_name['code_info']._options = None
  _QUERYCODERESPONSE.fields_by_name['code_info']._serialized_options = b'\320\336\037\001\352\336\037\000'
  _QUERYCODERESPONSE.fields_by_name['data']._options = None
  _QUERYCODERESPONSE.fields_by_name['data']._serialized_options = b'\352\336\037\004data'
  _QUERYCODERESPONSE._options = None
  _QUERYCODERESPONSE._serialized_options = b'\350\240\037\001'
  _QUERYCODESRESPONSE.fields_by_name['code_infos']._options = None
  _QUERYCODESRESPONSE.fields_by_name['code_infos']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPINNEDCODESRESPONSE.fields_by_name['code_ids']._options = None
  _QUERYPINNEDCODESRESPONSE.fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERY.methods_by_name['ContractInfo']._options = None
  _QUERY.methods_by_name['ContractInfo']._serialized_options = b'\202\323\344\223\002&\022$/cosmwasm/wasm/v1/contract/{address}'
  _QUERY.methods_by_name['ContractHistory']._options = None
  _QUERY.methods_by_name['ContractHistory']._serialized_options = b'\202\323\344\223\002.\022,/cosmwasm/wasm/v1/contract/{address}/history'
  _QUERY.methods_by_name['ContractsByCode']._options = None
  _QUERY.methods_by_name['ContractsByCode']._serialized_options = b'\202\323\344\223\002,\022*/cosmwasm/wasm/v1/code/{code_id}/contracts'
  _QUERY.methods_by_name['AllContractState']._options = None
  _QUERY.methods_by_name['AllContractState']._serialized_options = b'\202\323\344\223\002,\022*/cosmwasm/wasm/v1/contract/{address}/state'
  _QUERY.methods_by_name['RawContractState']._options = None
  _QUERY.methods_by_name['RawContractState']._serialized_options = b'\202\323\344\223\0027\0225/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}'
  _QUERY.methods_by_name['SmartContractState']._options = None
  _QUERY.methods_by_name['SmartContractState']._serialized_options = b'\202\323\344\223\0029\0227/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}'
  _QUERY.methods_by_name['Code']._options = None
  _QUERY.methods_by_name['Code']._serialized_options = b'\202\323\344\223\002\"\022 /cosmwasm/wasm/v1/code/{code_id}'
  _QUERY.methods_by_name['Codes']._options = None
  _QUERY.methods_by_name['Codes']._serialized_options = b'\202\323\344\223\002\030\022\026/cosmwasm/wasm/v1/code'
  _QUERY.methods_by_name['PinnedCodes']._options = None
  _QUERY.methods_by_name['PinnedCodes']._serialized_options = b'\202\323\344\223\002 \022\036/cosmwasm/wasm/v1/codes/pinned'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002 \022\036/cosmwasm/wasm/v1/codes/params'
  _QUERY.methods_by_name['ContractsByCreator']._options = None
  _QUERY.methods_by_name['ContractsByCreator']._serialized_options = b'\202\323\344\223\0027\0225/cosmwasm/wasm/v1/contracts/creator/{creator_address}'
  _globals['_QUERYCONTRACTINFOREQUEST']._serialized_start=195
  _globals['_QUERYCONTRACTINFOREQUEST']._serialized_end=238
  _globals['_QUERYCONTRACTINFORESPONSE']._serialized_start=240
  _globals['_QUERYCONTRACTINFORESPONSE']._serialized_end=364
  _globals['_QUERYCONTRACTHISTORYREQUEST']._serialized_start=366
  _globals['_QUERYCONTRACTHISTORYREQUEST']._serialized_end=472
  _globals['_QUERYCONTRACTHISTORYRESPONSE']._serialized_start=475
  _globals['_QUERYCONTRACTHISTORYRESPONSE']._serialized_end=638
  _globals['_QUERYCONTRACTSBYCODEREQUEST']._serialized_start=640
  _globals['_QUERYCONTRACTSBYCODEREQUEST']._serialized_end=746
  _globals['_QUERYCONTRACTSBYCODERESPONSE']._serialized_start=748
  _globals['_QUERYCONTRACTSBYCODERESPONSE']._serialized_end=858
  _globals['_QUERYALLCONTRACTSTATEREQUEST']._serialized_start=860
  _globals['_QUERYALLCONTRACTSTATEREQUEST']._serialized_end=967
  _globals['_QUERYALLCONTRACTSTATERESPONSE']._serialized_start=970
  _globals['_QUERYALLCONTRACTSTATERESPONSE']._serialized_end=1114
  _globals['_QUERYRAWCONTRACTSTATEREQUEST']._serialized_start=1116
  _globals['_QUERYRAWCONTRACTSTATEREQUEST']._serialized_end=1183
  _globals['_QUERYRAWCONTRACTSTATERESPONSE']._serialized_start=1185
  _globals['_QUERYRAWCONTRACTSTATERESPONSE']._serialized_end=1230
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST']._serialized_start=1232
  _globals['_QUERYSMARTCONTRACTSTATEREQUEST']._serialized_end=1325
  _globals['_QUERYSMARTCONTRACTSTATERESPONSE']._serialized_start=1327
  _globals['_QUERYSMARTCONTRACTSTATERESPONSE']._serialized_end=1398
  _globals['_QUERYCODEREQUEST']._serialized_start=1400
  _globals['_QUERYCODEREQUEST']._serialized_end=1435
  _globals['_CODEINFORESPONSE']._serialized_start=1438
  _globals['_CODEINFORESPONSE']._serialized_end=1674
  _globals['_QUERYCODERESPONSE']._serialized_start=1676
  _globals['_QUERYCODERESPONSE']._serialized_end=1790
  _globals['_QUERYCODESREQUEST']._serialized_start=1792
  _globals['_QUERYCODESREQUEST']._serialized_end=1871
  _globals['_QUERYCODESRESPONSE']._serialized_start=1874
  _globals['_QUERYCODESRESPONSE']._serialized_end=2022
  _globals['_QUERYPINNEDCODESREQUEST']._serialized_start=2024
  _globals['_QUERYPINNEDCODESREQUEST']._serialized_end=2109
  _globals['_QUERYPINNEDCODESRESPONSE']._serialized_start=2111
  _globals['_QUERYPINNEDCODESRESPONSE']._serialized_end=2229
  _globals['_QUERYPARAMSREQUEST']._serialized_start=2231
  _globals['_QUERYPARAMSREQUEST']._serialized_end=2251
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=2253
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=2327
  _globals['_QUERYCONTRACTSBYCREATORREQUEST']._serialized_start=2329
  _globals['_QUERYCONTRACTSBYCREATORREQUEST']._serialized_end=2446
  _globals['_QUERYCONTRACTSBYCREATORRESPONSE']._serialized_start=2448
  _globals['_QUERYCONTRACTSBYCREATORRESPONSE']._serialized_end=2570
  _globals['_QUERY']._serialized_start=2573
  _globals['_QUERY']._serialized_end=4304
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/msg/v1/msg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63osmos/msg/v1/msg.proto\x12\rcosmos.msg.v1\x1a google/protobuf/descriptor.proto:3\n\x07service\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\x8c\xa6\x05 \x01(\x08:2\n\x06signer\x12\x1f.google.protobuf.MessageOptions\x18\xf0\x8c\xa6\x05 \x03(\tB/Z-github.com/cosmos/cosmos-sdk/types/msgserviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.v1.msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(service)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(signer)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/types/msgservice'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/ocr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/ocr/v1beta1/ocr.proto\x12\x15injective.ocr.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"W\n\x06Params\x12\x12\n\nlink_denom\x18\x01 \x01(\t\x12\x1d\n\x15payout_block_interval\x18\x02 \x01(\x04\x12\x14\n\x0cmodule_admin\x18\x03 \x01(\t:\x04\xe8\xa0\x1f\x01\"\xcc\x01\n\nFeedConfig\x12\x0f\n\x07signers\x18\x01 \x03(\t\x12\x14\n\x0ctransmitters\x18\x02 \x03(\t\x12\t\n\x01\x66\x18\x03 \x01(\r\x12\x16\n\x0eonchain_config\x18\x04 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x05 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x06 \x01(\x0c\x12:\n\rmodule_params\x18\x07 \x01(\x0b\x32#.injective.ocr.v1beta1.ModuleParams\"~\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x1c\n\x14latest_config_digest\x18\x01 \x01(\x0c\x12\t\n\x01\x66\x18\x02 \x01(\r\x12\t\n\x01n\x18\x03 \x01(\r\x12\x14\n\x0c\x63onfig_count\x18\x04 \x01(\x04\x12\"\n\x1alatest_config_block_number\x18\x05 \x01(\x03\"\xb0\x03\n\x0cModuleParams\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x42\n\nmin_answer\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x42\n\nmax_answer\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12L\n\x14link_per_observation\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12M\n\x15link_per_transmission\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x12\n\nlink_denom\x18\x06 \x01(\t\x12\x16\n\x0eunique_reports\x18\x07 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x12\n\nfeed_admin\x18\t \x01(\t\x12\x15\n\rbilling_admin\x18\n \x01(\t\"\xaa\x01\n\x0e\x43ontractConfig\x12\x14\n\x0c\x63onfig_count\x18\x01 \x01(\x04\x12\x0f\n\x07signers\x18\x02 \x03(\t\x12\x14\n\x0ctransmitters\x18\x03 \x03(\t\x12\t\n\x01\x66\x18\x04 \x01(\r\x12\x16\n\x0eonchain_config\x18\x05 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x06 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x07 \x01(\x0c\"\x92\x01\n\x11SetConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x31\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xd0\x03\n\x0e\x46\x65\x65\x64Properties\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\t\n\x01\x66\x18\x02 \x01(\r\x12\x16\n\x0eonchain_config\x18\x03 \x01(\x0c\x12\x1f\n\x17offchain_config_version\x18\x04 \x01(\x04\x12\x17\n\x0foffchain_config\x18\x05 \x01(\x0c\x12\x42\n\nmin_answer\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x42\n\nmax_answer\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12L\n\x14link_per_observation\x18\x08 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12M\n\x15link_per_transmission\x18\t \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x16\n\x0eunique_reports\x18\n \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\"\xdf\x01\n\x16SetBatchConfigProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07signers\x18\x03 \x03(\t\x12\x14\n\x0ctransmitters\x18\x04 \x03(\t\x12\x12\n\nlink_denom\x18\x05 \x01(\t\x12>\n\x0f\x66\x65\x65\x64_properties\x18\x06 \x03(\x0b\x32%.injective.ocr.v1beta1.FeedProperties:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"*\n\x18OracleObservationsCounts\x12\x0e\n\x06\x63ounts\x18\x01 \x03(\r\"F\n\x11GasReimbursements\x12\x31\n\x0ereimbursements\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"7\n\x05Payee\x12\x18\n\x10transmitter_addr\x18\x01 \x01(\t\x12\x14\n\x0cpayment_addr\x18\x02 \x01(\t\"\x8e\x01\n\x0cTransmission\x12>\n\x06\x61nswer\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x1e\n\x16observations_timestamp\x18\x02 \x01(\x03\x12\x1e\n\x16transmission_timestamp\x18\x03 \x01(\x03\"-\n\rEpochAndRound\x12\r\n\x05\x65poch\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"\x81\x01\n\x06Report\x12\x1e\n\x16observations_timestamp\x18\x01 \x01(\x03\x12\x11\n\tobservers\x18\x02 \x01(\x0c\x12\x44\n\x0cobservations\x18\x03 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"g\n\x0cReportToSign\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\x12\r\n\x05round\x18\x03 \x01(\x04\x12\x12\n\nextra_hash\x18\x04 \x01(\x0c\x12\x0e\n\x06report\x18\x05 \x01(\x0c\"p\n\x0f\x45ventOraclePaid\x12\x18\n\x10transmitter_addr\x18\x01 \x01(\t\x12\x12\n\npayee_addr\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xd1\x01\n\x12\x45ventAnswerUpdated\x12?\n\x07\x63urrent\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12@\n\x08round_id\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x38\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\x9f\x01\n\rEventNewRound\x12@\n\x08round_id\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x12\n\nstarted_by\x18\x02 \x01(\t\x12\x38\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"8\n\x10\x45ventTransmitted\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\"\xe8\x02\n\x14\x45ventNewTransmission\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61ggregator_round_id\x18\x02 \x01(\r\x12>\n\x06\x61nswer\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x13\n\x0btransmitter\x18\x04 \x01(\t\x12\x1e\n\x16observations_timestamp\x18\x05 \x01(\x03\x12\x44\n\x0cobservations\x18\x06 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x11\n\tobservers\x18\x07 \x01(\x0c\x12\x15\n\rconfig_digest\x18\x08 \x01(\x0c\x12=\n\x0f\x65poch_and_round\x18\t \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"\xbc\x01\n\x0e\x45ventConfigSet\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12$\n\x1cprevious_config_block_number\x18\x02 \x01(\x03\x12\x31\n\x06\x63onfig\x18\x03 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\x12:\n\x0b\x63onfig_info\x18\x04 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfoBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.ocr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001'
  _MODULEPARAMS.fields_by_name['min_answer']._options = None
  _MODULEPARAMS.fields_by_name['min_answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MODULEPARAMS.fields_by_name['max_answer']._options = None
  _MODULEPARAMS.fields_by_name['max_answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MODULEPARAMS.fields_by_name['link_per_observation']._options = None
  _MODULEPARAMS.fields_by_name['link_per_observation']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MODULEPARAMS.fields_by_name['link_per_transmission']._options = None
  _MODULEPARAMS.fields_by_name['link_per_transmission']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _SETCONFIGPROPOSAL._options = None
  _SETCONFIGPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _FEEDPROPERTIES.fields_by_name['min_answer']._options = None
  _FEEDPROPERTIES.fields_by_name['min_answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _FEEDPROPERTIES.fields_by_name['max_answer']._options = None
  _FEEDPROPERTIES.fields_by_name['max_answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _FEEDPROPERTIES.fields_by_name['link_per_observation']._options = None
  _FEEDPROPERTIES.fields_by_name['link_per_observation']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _FEEDPROPERTIES.fields_by_name['link_per_transmission']._options = None
  _FEEDPROPERTIES.fields_by_name['link_per_transmission']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _SETBATCHCONFIGPROPOSAL._options = None
  _SETBATCHCONFIGPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _TRANSMISSION.fields_by_name['answer']._options = None
  _TRANSMISSION.fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _REPORT.fields_by_name['observations']._options = None
  _REPORT.fields_by_name['observations']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EVENTORACLEPAID.fields_by_name['amount']._options = None
  _EVENTORACLEPAID.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _EVENTANSWERUPDATED.fields_by_name['current']._options = None
  _EVENTANSWERUPDATED.fields_by_name['current']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _EVENTANSWERUPDATED.fields_by_name['round_id']._options = None
  _EVENTANSWERUPDATED.fields_by_name['round_id']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _EVENTANSWERUPDATED.fields_by_name['updated_at']._options = None
  _EVENTANSWERUPDATED.fields_by_name['updated_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _EVENTNEWROUND.fields_by_name['round_id']._options = None
  _EVENTNEWROUND.fields_by_name['round_id']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _EVENTNEWROUND.fields_by_name['started_at']._options = None
  _EVENTNEWROUND.fields_by_name['started_at']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _EVENTNEWTRANSMISSION.fields_by_name['answer']._options = None
  _EVENTNEWTRANSMISSION.fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EVENTNEWTRANSMISSION.fields_by_name['observations']._options = None
  _EVENTNEWTRANSMISSION.fields_by_name['observations']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _globals['_PARAMS']._serialized_start=172
  _globals['_PARAMS']._serialized_end=259
  _globals['_FEEDCONFIG']._serialized_start=262
  _globals['_FEEDCONFIG']._serialized_end=466
  _globals['_FEEDCONFIGINFO']._serialized_start=468
  _globals['_FEEDCONFIGINFO']._serialized_end=594
  _globals['_MODULEPARAMS']._serialized_start=597
  _globals['_MODULEPARAMS']._serialized_end=1029
  _globals['_CONTRACTCONFIG']._serialized_start=1032
  _globals['_CONTRACTCONFIG']._serialized_end=1202
  _globals['_SETCONFIGPROPOSAL']._serialized_start=1205
  _globals['_SETCONFIGPROPOSAL']._serialized_end=1351
  _globals['_FEEDPROPERTIES']._serialized_start=1354
  _globals['_FEEDPROPERTIES']._serialized_end=1818
  _globals['_SETBATCHCONFIGPROPOSAL']._serialized_start=1821
  _globals['_SETBATCHCONFIGPROPOSAL']._serialized_end=2044
  _globals['_ORACLEOBSERVATIONSCOUNTS']._serialized_start=2046
  _globals['_ORACLEOBSERVATIONSCOUNTS']._serialized_end=2088
  _globals['_GASREIMBURSEMENTS']._serialized_start=2090
  _globals['_GASREIMBURSEMENTS']._serialized_end=2160
  _globals['_PAYEE']._serialized_start=2162
  _globals['_PAYEE']._serialized_end=2217
  _globals['_TRANSMISSION']._serialized_start=2220
  _globals['_TRANSMISSION']._serialized_end=2362
  _globals['_EPOCHANDROUND']._serialized_start=2364
  _globals['_EPOCHANDROUND']._serialized_end=2409
  _globals['_REPORT']._serialized_start=2412
  _globals['_REPORT']._serialized_end=2541
  _globals['_REPORTTOSIGN']._serialized_start=2543
  _globals['_REPORTTOSIGN']._serialized_end=2646
  _globals['_EVENTORACLEPAID']._serialized_start=2648
  _globals['_EVENTORACLEPAID']._serialized_end=2760
  _globals['_EVENTANSWERUPDATED']._serialized_start=2763
  _globals['_EVENTANSWERUPDATED']._serialized_end=2972
  _globals['_EVENTNEWROUND']._serialized_start=2975
  _globals['_EVENTNEWROUND']._serialized_end=3134
  _globals['_EVENTTRANSMITTED']._serialized_start=3136
  _globals['_EVENTTRANSMITTED']._serialized_end=3192
  _globals['_EVENTNEWTRANSMISSION']._serialized_start=3195
  _globals['_EVENTNEWTRANSMISSION']._serialized_end=3555
  _globals['_EVENTCONFIGSET']._serialized_start=3558
  _globals['_EVENTCONFIGSET']._serialized_end=3746
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from testpb import bank_query_pb2 as testpb_dot_bank__query__pb2


class BankQueryServiceStub(object):
    """BankQueryService queries the state of the tables specified by testpb/bank.proto.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBalance = channel.unary_unary(
                '/testpb.BankQueryService/GetBalance',
                request_serializer=testpb_dot_bank__query__pb2.GetBalanceRequest.SerializeToString,
                response_deserializer=testpb_dot_bank__query__pb2.GetBalanceResponse.FromString,
                )
        self.ListBalance = channel.unary_unary(
                '/testpb.BankQueryService/ListBalance',
                request_serializer=testpb_dot_bank__query__pb2.ListBalanceRequest.SerializeToString,
                response_deserializer=testpb_dot_bank__query__pb2.ListBalanceResponse.FromString,
                )
        self.GetSupply = channel.unary_unary(
                '/testpb.BankQueryService/GetSupply',
                request_serializer=testpb_dot_bank__query__pb2.GetSupplyRequest.SerializeToString,
                response_deserializer=testpb_dot_bank__query__pb2.GetSupplyResponse.FromString,
                )
        self.ListSupply = channel.unary_unary(
                '/testpb.BankQueryService/ListSupply',
                request_serializer=testpb_dot_bank__query__pb2.ListSupplyRequest.SerializeToString,
                response_deserializer=testpb_dot_bank__query__pb2.ListSupplyResponse.FromString,
                )


class BankQueryServiceServicer(object):
    """BankQueryService queries the state of the tables specified by testpb/bank.proto.
    """

    def GetBalance(self, request, context):
        """Get queries the Balance table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBalance(self, request, context):
        """ListBalance queries the Balance table using prefix and range queries against defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSupply(self, request, context):
        """Get queries the Supply table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSupply(self, request, context):
        """ListSupply queries the Supply table using prefix and range queries against defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BankQueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBalance,
                    request_deserializer=testpb_dot_bank__query__pb2.GetBalanceRequest.FromString,
                    response_serializer=testpb_dot_bank__query__pb2.GetBalanceResponse.SerializeToString,
            ),
            'ListBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBalance,
                    request_deserializer=testpb_dot_bank__query__pb2.ListBalanceRequest.FromString,
                    response_serializer=testpb_dot_bank__query__pb2.ListBalanceResponse.SerializeToString,
            ),
            'GetSupply': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSupply,
                    request_deserializer=testpb_dot_bank__query__pb2.GetSupplyRequest.FromString,
                    response_serializer=testpb_dot_bank__query__pb2.GetSupplyResponse.SerializeToString,
            ),
            'ListSupply': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSupply,
                    request_deserializer=testpb_dot_bank__query__pb2.ListSupplyRequest.FromString,
                    response_serializer=testpb_dot_bank__query__pb2.ListSupplyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'testpb.BankQueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BankQueryService(object):
    """BankQueryService queries the state of the tables specified by testpb/bank.proto.
    """

    @staticmethod
    def GetBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.BankQueryService/GetBalance',
            testpb_dot_bank__query__pb2.GetBalanceRequest.SerializeToString,
            testpb_dot_bank__query__pb2.GetBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.BankQueryService/ListBalance',
            testpb_dot_bank__query__pb2.ListBalanceRequest.SerializeToString,
            testpb_dot_bank__query__pb2.ListBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSupply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.BankQueryService/GetSupply',
            testpb_dot_bank__query__pb2.GetSupplyRequest.SerializeToString,
            testpb_dot_bank__query__pb2.GetSupplyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSupply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.BankQueryService/ListSupply',
            testpb_dot_bank__query__pb2.ListSupplyRequest.SerializeToString,
            testpb_dot_bank__query__pb2.ListSupplyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/node/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/base/node/v1beta1/query.proto\x12\x18\x63osmos.base.node.v1beta1\x1a\x1cgoogle/api/annotations.proto\"\x0f\n\rConfigRequest\"+\n\x0e\x43onfigResponse\x12\x19\n\x11minimum_gas_price\x18\x01 \x01(\t2\x91\x01\n\x07Service\x12\x85\x01\n\x06\x43onfig\x12\'.cosmos.base.node.v1beta1.ConfigRequest\x1a(.cosmos.base.node.v1beta1.ConfigResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/base/node/v1beta1/configB/Z-github.com/cosmos/cosmos-sdk/client/grpc/nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.node.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/client/grpc/node'
  _SERVICE.methods_by_name['Config']._options = None
  _SERVICE.methods_by_name['Config']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/base/node/v1beta1/config'
  _globals['_CONFIGREQUEST']._serialized_start=96
  _globals['_CONFIGREQUEST']._serialized_end=111
  _globals['_CONFIGRESPONSE']._serialized_start=113
  _globals['_CONFIGRESPONSE']._serialized_end=156
  _globals['_SERVICE']._serialized_start=159
  _globals['_SERVICE']._serialized_end=304
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v3/solomachine.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v3/solomachine.proto\x12\x1fibc.lightclients.solomachine.v3\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xb4\x01\n\x0b\x43lientState\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\'\n\tis_frozen\x18\x02 \x01(\x08\x42\x14\xf2\xde\x1f\x10yaml:\"is_frozen\"\x12\x64\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v3.ConsensusStateB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\":\x04\x88\xa0\x1f\x00\"\x7f\n\x0e\x43onsensusState\x12?\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x15\xf2\xde\x1f\x11yaml:\"public_key\"\x12\x13\n\x0b\x64iversifier\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04:\x04\x88\xa0\x1f\x00\"\xb2\x01\n\x06Header\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12G\n\x0enew_public_key\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x19\xf2\xde\x1f\x15yaml:\"new_public_key\"\x12\x33\n\x0fnew_diversifier\x18\x04 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\"\xee\x01\n\x0cMisbehaviour\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x62\n\rsignature_one\x18\x02 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v3.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_one\"\x12\x62\n\rsignature_two\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v3.SignatureAndDataB\x18\xf2\xde\x1f\x14yaml:\"signature_two\":\x04\x88\xa0\x1f\x00\"Z\n\x10SignatureAndData\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\x04:\x04\x88\xa0\x1f\x00\"f\n\x18TimestampedSignatureData\x12\x31\n\x0esignature_data\x18\x01 \x01(\x0c\x42\x19\xf2\xde\x1f\x15yaml:\"signature_data\"\x12\x11\n\ttimestamp\x18\x02 \x01(\x04:\x04\x88\xa0\x1f\x00\"g\n\tSignBytes\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x13\n\x0b\x64iversifier\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c:\x04\x88\xa0\x1f\x00\"\x8a\x01\n\nHeaderData\x12\x41\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x16\xf2\xde\x1f\x12yaml:\"new_pub_key\"\x12\x33\n\x0fnew_diversifier\x18\x02 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"new_diversifier\":\x04\x88\xa0\x1f\x00\x42NZLgithub.com/cosmos/ibc-go/v7/modules/light-clients/06-solomachine;solomachineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v3.solomachine_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/cosmos/ibc-go/v7/modules/light-clients/06-solomachine;solomachine'
  _CLIENTSTATE.fields_by_name['is_frozen']._options = None
  _CLIENTSTATE.fields_by_name['is_frozen']._serialized_options = b'\362\336\037\020yaml:\"is_frozen\"'
  _CLIENTSTATE.fields_by_name['consensus_state']._options = None
  _CLIENTSTATE.fields_by_name['consensus_state']._serialized_options = b'\362\336\037\026yaml:\"consensus_state\"'
  _CLIENTSTATE._options = None
  _CLIENTSTATE._serialized_options = b'\210\240\037\000'
  _CONSENSUSSTATE.fields_by_name['public_key']._options = None
  _CONSENSUSSTATE.fields_by_name['public_key']._serialized_options = b'\362\336\037\021yaml:\"public_key\"'
  _CONSENSUSSTATE._options = None
  _CONSENSUSSTATE._serialized_options = b'\210\240\037\000'
  _HEADER.fields_by_name['new_public_key']._options = None
  _HEADER.fields_by_name['new_public_key']._serialized_options = b'\362\336\037\025yaml:\"new_public_key\"'
  _HEADER.fields_by_name['new_diversifier']._options = None
  _HEADER.fields_by_name['new_diversifier']._serialized_options = b'\362\336\037\026yaml:\"new_diversifier\"'
  _HEADER._options = None
  _HEADER._serialized_options = b'\210\240\037\000'
  _MISBEHAVIOUR.fields_by_name['signature_one']._options = None
  _MISBEHAVIOUR.fields_by_name['signature_one']._serialized_options = b'\362\336\037\024yaml:\"signature_one\"'
  _MISBEHAVIOUR.fields_by_name['signature_two']._options = None
  _MISBEHAVIOUR.fields_by_name['signature_two']._serialized_options = b'\362\336\037\024yaml:\"signature_two\"'
  _MISBEHAVIOUR._options = None
  _MISBEHAVIOUR._serialized_options = b'\210\240\037\000'
  _SIGNATUREANDDATA._options = None
  _SIGNATUREANDDATA._serialized_options = b'\210\240\037\000'
  _TIMESTAMPEDSIGNATUREDATA.fields_by_name['signature_data']._options = None
  _TIMESTAMPEDSIGNATUREDATA.fields_by_name['signature_data']._serialized_options = b'\362\336\037\025yaml:\"signature_data\"'
  _TIMESTAMPEDSIGNATUREDATA._options = None
  _TIMESTAMPEDSIGNATUREDATA._serialized_options = b'\210\240\037\000'
  _SIGNBYTES._options = None
  _SIGNBYTES._serialized_options = b'\210\240\037\000'
  _HEADERDATA.fields_by_name['new_pub_key']._options = None
  _HEADERDATA.fields_by_name['new_pub_key']._serialized_options = b'\362\336\037\022yaml:\"new_pub_key\"'
  _HEADERDATA.fields_by_name['new_diversifier']._options = None
  _HEADERDATA.fields_by_name['new_diversifier']._serialized_options = b'\362\336\037\026yaml:\"new_diversifier\"'
  _HEADERDATA._options = None
  _HEADERDATA._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATE']._serialized_start=136
  _globals['_CLIENTSTATE']._serialized_end=316
  _globals['_CONSENSUSSTATE']._serialized_start=318
  _globals['_CONSENSUSSTATE']._serialized_end=445
  _globals['_HEADER']._serialized_start=448
  _globals['_HEADER']._serialized_end=626
  _globals['_MISBEHAVIOUR']._serialized_start=629
  _globals['_MISBEHAVIOUR']._serialized_end=867
  _globals['_SIGNATUREANDDATA']._serialized_start=869
  _globals['_SIGNATUREANDDATA']._serialized_end=959
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_start=961
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_end=1063
  _globals['_SIGNBYTES']._serialized_start=1065
  _globals['_SIGNBYTES']._serialized_end=1168
  _globals['_HEADERDATA']._serialized_start=1171
  _globals['_HEADERDATA']._serialized_end=1309
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.distribution.v1beta1 import query_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service for distribution module.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/Params',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.ValidatorDistributionInfo = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/ValidatorDistributionInfo',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorDistributionInfoRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorDistributionInfoResponse.FromString,
                )
        self.ValidatorOutstandingRewards = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/ValidatorOutstandingRewards',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsResponse.FromString,
                )
        self.ValidatorCommission = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/ValidatorCommission',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionResponse.FromString,
                )
        self.ValidatorSlashes = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/ValidatorSlashes',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesResponse.FromString,
                )
        self.DelegationRewards = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/DelegationRewards',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsResponse.FromString,
                )
        self.DelegationTotalRewards = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/DelegationTotalRewards',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsResponse.FromString,
                )
        self.DelegatorValidators = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/DelegatorValidators',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString,
                )
        self.DelegatorWithdrawAddress = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/DelegatorWithdrawAddress',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressResponse.FromString,
                )
        self.CommunityPool = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Query/CommunityPool',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolRequest.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service for distribution module.
    """

    def Params(self, request, context):
        """Params queries params of the distribution module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorDistributionInfo(self, request, context):
        """ValidatorDistributionInfo queries validator commission and self-delegation rewards for validator
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorOutstandingRewards(self, request, context):
        """ValidatorOutstandingRewards queries rewards of a validator address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorCommission(self, request, context):
        """ValidatorCommission queries accumulated commission for a validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorSlashes(self, request, context):
        """ValidatorSlashes queries slash events of a validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegationRewards(self, request, context):
        """DelegationRewards queries the total rewards accrued by a delegation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegationTotalRewards(self, request, context):
        """DelegationTotalRewards queries the total rewards accrued by a each
        validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorValidators(self, request, context):
        """DelegatorValidators queries the validators of a delegator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelegatorWithdrawAddress(self, request, context):
        """DelegatorWithdrawAddress queries withdraw address of a delegator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommunityPool(self, request, context):
        """CommunityPool queries the community pool coins.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'ValidatorDistributionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorDistributionInfo,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorDistributionInfoRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorDistributionInfoResponse.SerializeToString,
            ),
            'ValidatorOutstandingRewards': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorOutstandingRewards,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsResponse.SerializeToString,
            ),
            'ValidatorCommission': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorCommission,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionResponse.SerializeToString,
            ),
            'ValidatorSlashes': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorSlashes,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesResponse.SerializeToString,
            ),
            'DelegationRewards': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegationRewards,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsResponse.SerializeToString,
            ),
            'DelegationTotalRewards': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegationTotalRewards,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsResponse.SerializeToString,
            ),
            'DelegatorValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegatorValidators,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.SerializeToString,
            ),
            'DelegatorWithdrawAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.DelegatorWithdrawAddress,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressResponse.SerializeToString,
            ),
            'CommunityPool': grpc.unary_unary_rpc_method_handler(
                    servicer.CommunityPool,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolRequest.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.distribution.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service for distribution module.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/Params',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorDistributionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorDistributionInfo',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorDistributionInfoRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorDistributionInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorOutstandingRewards(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorOutstandingRewards',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorOutstandingRewardsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorCommission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorCommission',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorCommissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidatorSlashes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/ValidatorSlashes',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryValidatorSlashesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegationRewards(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegationRewards',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationRewardsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegationTotalRewards(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegationTotalRewards',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegationTotalRewardsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegatorValidators',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorValidatorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DelegatorWithdrawAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/DelegatorWithdrawAddress',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryDelegatorWithdrawAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommunityPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.distribution.v1beta1.Query/CommunityPool',
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolRequest.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_query__pb2.QueryCommunityPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: amino/amino.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61mino/amino.proto\x12\x05\x61mino\x1a google/protobuf/descriptor.proto:0\n\x04name\x12\x1f.google.protobuf.MessageOptions\x18\xf1\x8c\xa6\x05 \x01(\t:<\n\x10message_encoding\x12\x1f.google.protobuf.MessageOptions\x18\xf2\x8c\xa6\x05 \x01(\t:2\n\x08\x65ncoding\x12\x1d.google.protobuf.FieldOptions\x18\xf3\x8c\xa6\x05 \x01(\t:4\n\nfield_name\x12\x1d.google.protobuf.FieldOptions\x18\xf4\x8c\xa6\x05 \x01(\t:8\n\x0e\x64ont_omitempty\x12\x1d.google.protobuf.FieldOptions\x18\xf5\x8c\xa6\x05 \x01(\x08\x42-Z+github.com/cosmos/cosmos-sdk/types/tx/aminob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'amino.amino_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(name)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_encoding)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(encoding)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_name)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(dont_omitempty)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/types/tx/amino'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/reflection/v1beta1/reflection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/cosmos/base/reflection/v1beta1/reflection.proto\x12\x1e\x63osmos.base.reflection.v1beta1\x1a\x1cgoogle/api/annotations.proto\"\x1a\n\x18ListAllInterfacesRequest\"4\n\x19ListAllInterfacesResponse\x12\x17\n\x0finterface_names\x18\x01 \x03(\t\"4\n\x1aListImplementationsRequest\x12\x16\n\x0einterface_name\x18\x01 \x01(\t\"C\n\x1bListImplementationsResponse\x12$\n\x1cimplementation_message_names\x18\x01 \x03(\t2\xb8\x03\n\x11ReflectionService\x12\xbc\x01\n\x11ListAllInterfaces\x12\x38.cosmos.base.reflection.v1beta1.ListAllInterfacesRequest\x1a\x39.cosmos.base.reflection.v1beta1.ListAllInterfacesResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmos/base/reflection/v1beta1/interfaces\x12\xe3\x01\n\x13ListImplementations\x12:.cosmos.base.reflection.v1beta1.ListImplementationsRequest\x1a;.cosmos.base.reflection.v1beta1.ListImplementationsResponse\"S\x82\xd3\xe4\x93\x02M\x12K/cosmos/base/reflection/v1beta1/interfaces/{interface_name}/implementationsB5Z3github.com/cosmos/cosmos-sdk/client/grpc/reflectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.reflection.v1beta1.reflection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/cosmos/cosmos-sdk/client/grpc/reflection'
  _REFLECTIONSERVICE.methods_by_name['ListAllInterfaces']._options = None
  _REFLECTIONSERVICE.methods_by_name['ListAllInterfaces']._serialized_options = b'\202\323\344\223\002,\022*/cosmos/base/reflection/v1beta1/interfaces'
  _REFLECTIONSERVICE.methods_by_name['ListImplementations']._options = None
  _REFLECTIONSERVICE.methods_by_name['ListImplementations']._serialized_options = b'\202\323\344\223\002M\022K/cosmos/base/reflection/v1beta1/interfaces/{interface_name}/implementations'
  _globals['_LISTALLINTERFACESREQUEST']._serialized_start=113
  _globals['_LISTALLINTERFACESREQUEST']._serialized_end=139
  _globals['_LISTALLINTERFACESRESPONSE']._serialized_start=141
  _globals['_LISTALLINTERFACESRESPONSE']._serialized_end=193
  _globals['_LISTIMPLEMENTATIONSREQUEST']._serialized_start=195
  _globals['_LISTIMPLEMENTATIONSREQUEST']._serialized_end=247
  _globals['_LISTIMPLEMENTATIONSRESPONSE']._serialized_start=249
  _globals['_LISTIMPLEMENTATIONSRESPONSE']._serialized_end=316
  _globals['_REFLECTIONSERVICE']._serialized_start=319
  _globals['_REFLECTIONSERVICE']._serialized_end=759
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/ics23/v1/proofs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/ics23/v1/proofs.proto\x12\x0f\x63osmos.ics23.v1\"{\n\x0e\x45xistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12%\n\x04leaf\x18\x03 \x01(\x0b\x32\x17.cosmos.ics23.v1.LeafOp\x12&\n\x04path\x18\x04 \x03(\x0b\x32\x18.cosmos.ics23.v1.InnerOp\"\x7f\n\x11NonExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12-\n\x04left\x18\x02 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProof\x12.\n\x05right\x18\x03 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProof\"\xef\x01\n\x0f\x43ommitmentProof\x12\x30\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProofH\x00\x12\x36\n\x08nonexist\x18\x02 \x01(\x0b\x32\".cosmos.ics23.v1.NonExistenceProofH\x00\x12,\n\x05\x62\x61tch\x18\x03 \x01(\x0b\x32\x1b.cosmos.ics23.v1.BatchProofH\x00\x12;\n\ncompressed\x18\x04 \x01(\x0b\x32%.cosmos.ics23.v1.CompressedBatchProofH\x00\x42\x07\n\x05proof\"\xc8\x01\n\x06LeafOp\x12%\n\x04hash\x18\x01 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOp\x12,\n\x0bprehash_key\x18\x02 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOp\x12.\n\rprehash_value\x18\x03 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOp\x12)\n\x06length\x18\x04 \x01(\x0e\x32\x19.cosmos.ics23.v1.LengthOp\x12\x0e\n\x06prefix\x18\x05 \x01(\x0c\"P\n\x07InnerOp\x12%\n\x04hash\x18\x01 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOp\x12\x0e\n\x06prefix\x18\x02 \x01(\x0c\x12\x0e\n\x06suffix\x18\x03 \x01(\x0c\"\xb4\x01\n\tProofSpec\x12*\n\tleaf_spec\x18\x01 \x01(\x0b\x32\x17.cosmos.ics23.v1.LeafOp\x12.\n\ninner_spec\x18\x02 \x01(\x0b\x32\x1a.cosmos.ics23.v1.InnerSpec\x12\x11\n\tmax_depth\x18\x03 \x01(\x05\x12\x11\n\tmin_depth\x18\x04 \x01(\x05\x12%\n\x1dprehash_key_before_comparison\x18\x05 \x01(\x08\"\xa6\x01\n\tInnerSpec\x12\x13\n\x0b\x63hild_order\x18\x01 \x03(\x05\x12\x12\n\nchild_size\x18\x02 \x01(\x05\x12\x19\n\x11min_prefix_length\x18\x03 \x01(\x05\x12\x19\n\x11max_prefix_length\x18\x04 \x01(\x05\x12\x13\n\x0b\x65mpty_child\x18\x05 \x01(\x0c\x12%\n\x04hash\x18\x06 \x01(\x0e\x32\x17.cosmos.ics23.v1.HashOp\":\n\nBatchProof\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.cosmos.ics23.v1.BatchEntry\"\x7f\n\nBatchEntry\x12\x30\n\x05\x65xist\x18\x01 \x01(\x0b\x32\x1f.cosmos.ics23.v1.ExistenceProofH\x00\x12\x36\n\x08nonexist\x18\x02 \x01(\x0b\x32\".cosmos.ics23.v1.NonExistenceProofH\x00\x42\x07\n\x05proof\"\x7f\n\x14\x43ompressedBatchProof\x12\x36\n\x07\x65ntries\x18\x01 \x03(\x0b\x32%.cosmos.ics23.v1.CompressedBatchEntry\x12/\n\rlookup_inners\x18\x02 \x03(\x0b\x32\x18.cosmos.ics23.v1.InnerOp\"\x9d\x01\n\x14\x43ompressedBatchEntry\x12:\n\x05\x65xist\x18\x01 \x01(\x0b\x32).cosmos.ics23.v1.CompressedExistenceProofH\x00\x12@\n\x08nonexist\x18\x02 \x01(\x0b\x32,.cosmos.ics23.v1.CompressedNonExistenceProofH\x00\x42\x07\n\x05proof\"k\n\x18\x43ompressedExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12%\n\x04leaf\x18\x03 \x01(\x0b\x32\x17.cosmos.ics23.v1.LeafOp\x12\x0c\n\x04path\x18\x04 \x03(\x05\"\x9d\x01\n\x1b\x43ompressedNonExistenceProof\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x37\n\x04left\x18\x02 \x01(\x0b\x32).cosmos.ics23.v1.CompressedExistenceProof\x12\x38\n\x05right\x18\x03 \x01(\x0b\x32).cosmos.ics23.v1.CompressedExistenceProof*e\n\x06HashOp\x12\x0b\n\x07NO_HASH\x10\x00\x12\n\n\x06SHA256\x10\x01\x12\n\n\x06SHA512\x10\x02\x12\n\n\x06KECCAK\x10\x03\x12\r\n\tRIPEMD160\x10\x04\x12\x0b\n\x07\x42ITCOIN\x10\x05\x12\x0e\n\nSHA512_256\x10\x06*\xab\x01\n\x08LengthOp\x12\r\n\tNO_PREFIX\x10\x00\x12\r\n\tVAR_PROTO\x10\x01\x12\x0b\n\x07VAR_RLP\x10\x02\x12\x0f\n\x0b\x46IXED32_BIG\x10\x03\x12\x12\n\x0e\x46IXED32_LITTLE\x10\x04\x12\x0f\n\x0b\x46IXED64_BIG\x10\x05\x12\x12\n\x0e\x46IXED64_LITTLE\x10\x06\x12\x14\n\x10REQUIRE_32_BYTES\x10\x07\x12\x14\n\x10REQUIRE_64_BYTES\x10\x08\x42\"Z github.com/cosmos/ics23/go;ics23b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.ics23.v1.proofs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z github.com/cosmos/ics23/go;ics23'
  _globals['_HASHOP']._serialized_start=1929
  _globals['_HASHOP']._serialized_end=2030
  _globals['_LENGTHOP']._serialized_start=2033
  _globals['_LENGTHOP']._serialized_end=2204
  _globals['_EXISTENCEPROOF']._serialized_start=49
  _globals['_EXISTENCEPROOF']._serialized_end=172
  _globals['_NONEXISTENCEPROOF']._serialized_start=174
  _globals['_NONEXISTENCEPROOF']._serialized_end=301
  _globals['_COMMITMENTPROOF']._serialized_start=304
  _globals['_COMMITMENTPROOF']._serialized_end=543
  _globals['_LEAFOP']._serialized_start=546
  _globals['_LEAFOP']._serialized_end=746
  _globals['_INNEROP']._serialized_start=748
  _globals['_INNEROP']._serialized_end=828
  _globals['_PROOFSPEC']._serialized_start=831
  _globals['_PROOFSPEC']._serialized_end=1011
  _globals['_INNERSPEC']._serialized_start=1014
  _globals['_INNERSPEC']._serialized_end=1180
  _globals['_BATCHPROOF']._serialized_start=1182
  _globals['_BATCHPROOF']._serialized_end=1240
  _globals['_BATCHENTRY']._serialized_start=1242
  _globals['_BATCHENTRY']._serialized_end=1369
  _globals['_COMPRESSEDBATCHPROOF']._serialized_start=1371
  _globals['_COMPRESSEDBATCHPROOF']._serialized_end=1498
  _globals['_COMPRESSEDBATCHENTRY']._serialized_start=1501
  _globals['_COMPRESSEDBATCHENTRY']._serialized_end=1658
  _globals['_COMPRESSEDEXISTENCEPROOF']._serialized_start=1660
  _globals['_COMPRESSEDEXISTENCEPROOF']._serialized_end=1767
  _globals['_COMPRESSEDNONEXISTENCEPROOF']._serialized_start=1770
  _globals['_COMPRESSEDNONEXISTENCEPROOF']._serialized_end=1927
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/mint/v1beta1/mint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/mint/v1beta1/mint.proto\x12\x13\x63osmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xb2\x01\n\x06Minter\x12O\n\tinflation\x18\x01 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12W\n\x11\x61nnual_provisions\x18\x02 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\"\xb2\x03\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12[\n\x15inflation_rate_change\x18\x02 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12S\n\rinflation_max\x18\x03 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12S\n\rinflation_min\x18\x04 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12Q\n\x0bgoal_bonded\x18\x05 \x01(\tB<\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xd2\xb4-\ncosmos.Dec\x12\x17\n\x0f\x62locks_per_year\x18\x06 \x01(\x04:!\x98\xa0\x1f\x00\x8a\xe7\xb0*\x18\x63osmos-sdk/x/mint/ParamsB+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.mint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
  _MINTER.fields_by_name['inflation']._options = None
  _MINTER.fields_by_name['inflation']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _MINTER.fields_by_name['annual_provisions']._options = None
  _MINTER.fields_by_name['annual_provisions']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['inflation_rate_change']._options = None
  _PARAMS.fields_by_name['inflation_rate_change']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['inflation_max']._options = None
  _PARAMS.fields_by_name['inflation_max']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['inflation_min']._options = None
  _PARAMS.fields_by_name['inflation_min']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['goal_bonded']._options = None
  _PARAMS.fields_by_name['goal_bonded']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\322\264-\ncosmos.Dec'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000\212\347\260*\030cosmos-sdk/x/mint/Params'
  _globals['_MINTER']._serialized_start=124
  _globals['_MINTER']._serialized_end=302
  _globals['_PARAMS']._serialized_start=305
  _globals['_PARAMS']._serialized_end=739
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ibc/applications/transfer/v1/query.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a+ibc/applications/transfer/v1/transfer.proto\x1a\x1cgoogle/api/annotations.proto\"&\n\x16QueryDenomTraceRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"X\n\x17QueryDenomTraceResponse\x12=\n\x0b\x64\x65nom_trace\x18\x01 \x01(\x0b\x32(.ibc.applications.transfer.v1.DenomTrace\"U\n\x17QueryDenomTracesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xa7\x01\n\x18QueryDenomTracesResponse\x12N\n\x0c\x64\x65nom_traces\x18\x01 \x03(\x0b\x32(.ibc.applications.transfer.v1.DenomTraceB\x0e\xc8\xde\x1f\x00\xaa\xdf\x1f\x06Traces\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x14\n\x12QueryParamsRequest\"K\n\x13QueryParamsResponse\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32$.ibc.applications.transfer.v1.Params\"&\n\x15QueryDenomHashRequest\x12\r\n\x05trace\x18\x01 \x01(\t\"&\n\x16QueryDenomHashResponse\x12\x0c\n\x04hash\x18\x01 \x01(\t\"@\n\x19QueryEscrowAddressRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\"4\n\x1aQueryEscrowAddressResponse\x12\x16\n\x0e\x65scrow_address\x18\x01 \x01(\t\"0\n\x1fQueryTotalEscrowForDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"S\n QueryTotalEscrowForDenomResponse\x12/\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x32\xd8\x08\n\x05Query\x12\xaf\x01\n\nDenomTrace\x12\x34.ibc.applications.transfer.v1.QueryDenomTraceRequest\x1a\x35.ibc.applications.transfer.v1.QueryDenomTraceResponse\"4\x82\xd3\xe4\x93\x02.\x12,/ibc/apps/transfer/v1/denom_traces/{hash=**}\x12\xa8\x01\n\x0b\x44\x65nomTraces\x12\x35.ibc.applications.transfer.v1.QueryDenomTracesRequest\x1a\x36.ibc.applications.transfer.v1.QueryDenomTracesResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/ibc/apps/transfer/v1/denom_traces\x12\x93\x01\n\x06Params\x12\x30.ibc.applications.transfer.v1.QueryParamsRequest\x1a\x31.ibc.applications.transfer.v1.QueryParamsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/transfer/v1/params\x12\xad\x01\n\tDenomHash\x12\x33.ibc.applications.transfer.v1.QueryDenomHashRequest\x1a\x34.ibc.applications.transfer.v1.QueryDenomHashResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/apps/transfer/v1/denom_hashes/{trace=**}\x12\xd6\x01\n\rEscrowAddress\x12\x37.ibc.applications.transfer.v1.QueryEscrowAddressRequest\x1a\x38.ibc.applications.transfer.v1.QueryEscrowAddressResponse\"R\x82\xd3\xe4\x93\x02L\x12J/ibc/apps/transfer/v1/channels/{channel_id}/ports/{port_id}/escrow_address\x12\xd2\x01\n\x13TotalEscrowForDenom\x12=.ibc.applications.transfer.v1.QueryTotalEscrowForDenomRequest\x1a>.ibc.applications.transfer.v1.QueryTotalEscrowForDenomResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/ibc/apps/transfer/v1/denoms/{denom=**}/total_escrowB9Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/types'
  _QUERYDENOMTRACESRESPONSE.fields_by_name['denom_traces']._options = None
  _QUERYDENOMTRACESRESPONSE.fields_by_name['denom_traces']._serialized_options = b'\310\336\037\000\252\337\037\006Traces'
  _QUERYTOTALESCROWFORDENOMRESPONSE.fields_by_name['amount']._options = None
  _QUERYTOTALESCROWFORDENOMRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['DenomTrace']._options = None
  _QUERY.methods_by_name['DenomTrace']._serialized_options = b'\202\323\344\223\002.\022,/ibc/apps/transfer/v1/denom_traces/{hash=**}'
  _QUERY.methods_by_name['DenomTraces']._options = None
  _QUERY.methods_by_name['DenomTraces']._serialized_options = b'\202\323\344\223\002$\022\"/ibc/apps/transfer/v1/denom_traces'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\036\022\034/ibc/apps/transfer/v1/params'
  _QUERY.methods_by_name['DenomHash']._options = None
  _QUERY.methods_by_name['DenomHash']._serialized_options = b'\202\323\344\223\002/\022-/ibc/apps/transfer/v1/denom_hashes/{trace=**}'
  _QUERY.methods_by_name['EscrowAddress']._options = None
  _QUERY.methods_by_name['EscrowAddress']._serialized_options = b'\202\323\344\223\002L\022J/ibc/apps/transfer/v1/channels/{channel_id}/ports/{port_id}/escrow_address'
  _QUERY.methods_by_name['TotalEscrowForDenom']._options = None
  _QUERY.methods_by_name['TotalEscrowForDenom']._serialized_options = b'\202\323\344\223\0026\0224/ibc/apps/transfer/v1/denoms/{denom=**}/total_escrow'
  _globals['_QUERYDENOMTRACEREQUEST']._serialized_start=247
  _globals['_QUERYDENOMTRACEREQUEST']._serialized_end=285
  _globals['_QUERYDENOMTRACERESPONSE']._serialized_start=287
  _globals['_QUERYDENOMTRACERESPONSE']._serialized_end=375
  _globals['_QUERYDENOMTRACESREQUEST']._serialized_start=377
  _globals['_QUERYDENOMTRACESREQUEST']._serialized_end=462
  _globals['_QUERYDENOMTRACESRESPONSE']._serialized_start=465
  _globals['_QUERYDENOMTRACESRESPONSE']._serialized_end=632
  _globals['_QUERYPARAMSREQUEST']._serialized_start=634
  _globals['_QUERYPARAMSREQUEST']._serialized_end=654
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=656
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=731
  _globals['_QUERYDENOMHASHREQUEST']._serialized_start=733
  _globals['_QUERYDENOMHASHREQUEST']._serialized_end=771
  _globals['_QUERYDENOMHASHRESPONSE']._serialized_start=773
  _globals['_QUERYDENOMHASHRESPONSE']._serialized_end=811
  _globals['_QUERYESCROWADDRESSREQUEST']._serialized_start=813
  _globals['_QUERYESCROWADDRESSREQUEST']._serialized_end=877
  _globals['_QUERYESCROWADDRESSRESPONSE']._serialized_start=879
  _globals['_QUERYESCROWADDRESSRESPONSE']._serialized_end=931
  _globals['_QUERYTOTALESCROWFORDENOMREQUEST']._serialized_start=933
  _globals['_QUERYTOTALESCROWFORDENOMREQUEST']._serialized_end=981
  _globals['_QUERYTOTALESCROWFORDENOMRESPONSE']._serialized_start=983
  _globals['_QUERYTOTALESCROWFORDENOMRESPONSE']._serialized_end=1066
  _globals['_QUERY']._serialized_start=1069
  _globals['_QUERY']._serialized_end=2181
# @@protoc_insertion_point(module_scope)
